@@ -1,7 +1,7 @@
 package App::ListSoftwareLicenses;
 
-our $DATE = '2015-02-04'; # DATE
-our $VERSION = '0.04'; # VERSION
+our $DATE = '2015-07-15'; # DATE
+our $VERSION = '0.05'; # VERSION
 
 use 5.010001;
 use strict;
@@ -93,7 +93,7 @@ my $table_data = $cache->compute(
         $data;
     });
 
-use Perinci::Sub::Gen::AccessTable 0.23 qw(gen_read_table_func);
+use Perinci::Sub::Gen::AccessTable qw(gen_read_table_func);
 
 my $res = gen_read_table_func(
     name       => 'list_software_licenses',
@@ -106,7 +106,7 @@ my $res = gen_read_table_func(
 die "Can't generate list_software_licenses function: $res->[0] - $res->[1]"
     unless $res->[0] == 200;
 
-$SPEC{list_software_licenses}{args}{q}{pos} = 0;
+$SPEC{list_software_licenses}{args}{query}{pos} = 0;
 $SPEC{list_software_licenses}{examples} = [
     {
         argv    => [qw/perl/],
@@ -129,24 +129,30 @@ App::ListSoftwareLicenses - List all Software::License's
 
 =head1 VERSION
 
-This document describes version 0.04 of App::ListSoftwareLicenses (from Perl distribution App-ListSoftwareLicenses), released on 2015-02-04.
+This document describes version 0.05 of App::ListSoftwareLicenses (from Perl distribution App-ListSoftwareLicenses), released on 2015-07-15.
+
+=head1 SEE ALSO
+
+L<Software::License>
+
+L<App::Software::License> to print out license text
 
 =head1 FUNCTIONS
 
 
 =head2 list_software_licenses(%args) -> [status, msg, result, meta]
 
-{en_US List all Software::License's}.
+List all Software::License's.
 
 Examples:
 
- list_software_licenses( q => "perl");
+ list_software_licenses( query => "perl");
 
 
 String search.
 
 
-{en_US REPLACE ME}
+REPLACE ME
 
 Arguments ('*' denotes required arguments):
 
@@ -154,394 +160,388 @@ Arguments ('*' denotes required arguments):
 
 =item * B<detail> => I<bool> (default: 0)
 
-{en_US Return array of full records instead of just ID fields}.
+Return array of full records instead of just ID fields.
 
-{en_US 
 By default, only the key (ID) field is returned per result entry.
-}
 
 =item * B<fields> => I<array[str]>
 
-{en_US Select fields to return}.
+Select fields to return.
 
 =item * B<meta2_name> => I<str>
 
-{en_US Only return records where the 'meta2_name' field equals specified value}.
+Only return records where the 'meta2_name' field equals specified value.
 
 =item * B<meta2_name.contains> => I<str>
 
-{en_US Only return records where the 'meta2_name' field contains specified text}.
+Only return records where the 'meta2_name' field contains specified text.
 
 =item * B<meta2_name.in> => I<array[str]>
 
-{en_US Only return records where the 'meta2_name' field is in the specified values}.
+Only return records where the 'meta2_name' field is in the specified values.
 
 =item * B<meta2_name.is> => I<str>
 
-{en_US Only return records where the 'meta2_name' field equals specified value}.
+Only return records where the 'meta2_name' field equals specified value.
 
 =item * B<meta2_name.isnt> => I<str>
 
-{en_US Only return records where the 'meta2_name' field does not equal specified value}.
+Only return records where the 'meta2_name' field does not equal specified value.
 
 =item * B<meta2_name.max> => I<str>
 
-{en_US Only return records where the 'meta2_name' field is less than or equal to specified value}.
+Only return records where the 'meta2_name' field is less than or equal to specified value.
 
 =item * B<meta2_name.min> => I<str>
 
-{en_US Only return records where the 'meta2_name' field is greater than or equal to specified value}.
+Only return records where the 'meta2_name' field is greater than or equal to specified value.
 
 =item * B<meta2_name.not_contains> => I<str>
 
-{en_US Only return records where the 'meta2_name' field does not contain specified text}.
+Only return records where the 'meta2_name' field does not contain specified text.
 
 =item * B<meta2_name.not_in> => I<array[str]>
 
-{en_US Only return records where the 'meta2_name' field is not in the specified values}.
+Only return records where the 'meta2_name' field is not in the specified values.
 
 =item * B<meta2_name.xmax> => I<str>
 
-{en_US Only return records where the 'meta2_name' field is less than specified value}.
+Only return records where the 'meta2_name' field is less than specified value.
 
 =item * B<meta2_name.xmin> => I<str>
 
-{en_US Only return records where the 'meta2_name' field is greater than specified value}.
+Only return records where the 'meta2_name' field is greater than specified value.
 
 =item * B<meta_name> => I<str>
 
-{en_US Only return records where the 'meta_name' field equals specified value}.
+Only return records where the 'meta_name' field equals specified value.
 
 =item * B<meta_name.contains> => I<str>
 
-{en_US Only return records where the 'meta_name' field contains specified text}.
+Only return records where the 'meta_name' field contains specified text.
 
 =item * B<meta_name.in> => I<array[str]>
 
-{en_US Only return records where the 'meta_name' field is in the specified values}.
+Only return records where the 'meta_name' field is in the specified values.
 
 =item * B<meta_name.is> => I<str>
 
-{en_US Only return records where the 'meta_name' field equals specified value}.
+Only return records where the 'meta_name' field equals specified value.
 
 =item * B<meta_name.isnt> => I<str>
 
-{en_US Only return records where the 'meta_name' field does not equal specified value}.
+Only return records where the 'meta_name' field does not equal specified value.
 
 =item * B<meta_name.max> => I<str>
 
-{en_US Only return records where the 'meta_name' field is less than or equal to specified value}.
+Only return records where the 'meta_name' field is less than or equal to specified value.
 
 =item * B<meta_name.min> => I<str>
 
-{en_US Only return records where the 'meta_name' field is greater than or equal to specified value}.
+Only return records where the 'meta_name' field is greater than or equal to specified value.
 
 =item * B<meta_name.not_contains> => I<str>
 
-{en_US Only return records where the 'meta_name' field does not contain specified text}.
+Only return records where the 'meta_name' field does not contain specified text.
 
 =item * B<meta_name.not_in> => I<array[str]>
 
-{en_US Only return records where the 'meta_name' field is not in the specified values}.
+Only return records where the 'meta_name' field is not in the specified values.
 
 =item * B<meta_name.xmax> => I<str>
 
-{en_US Only return records where the 'meta_name' field is less than specified value}.
+Only return records where the 'meta_name' field is less than specified value.
 
 =item * B<meta_name.xmin> => I<str>
 
-{en_US Only return records where the 'meta_name' field is greater than specified value}.
+Only return records where the 'meta_name' field is greater than specified value.
 
 =item * B<module> => I<str>
 
-{en_US Only return records where the 'module' field equals specified value}.
+Only return records where the 'module' field equals specified value.
 
 =item * B<module.contains> => I<str>
 
-{en_US Only return records where the 'module' field contains specified text}.
+Only return records where the 'module' field contains specified text.
 
 =item * B<module.in> => I<array[str]>
 
-{en_US Only return records where the 'module' field is in the specified values}.
+Only return records where the 'module' field is in the specified values.
 
 =item * B<module.is> => I<str>
 
-{en_US Only return records where the 'module' field equals specified value}.
+Only return records where the 'module' field equals specified value.
 
 =item * B<module.isnt> => I<str>
 
-{en_US Only return records where the 'module' field does not equal specified value}.
+Only return records where the 'module' field does not equal specified value.
 
 =item * B<module.max> => I<str>
 
-{en_US Only return records where the 'module' field is less than or equal to specified value}.
+Only return records where the 'module' field is less than or equal to specified value.
 
 =item * B<module.min> => I<str>
 
-{en_US Only return records where the 'module' field is greater than or equal to specified value}.
+Only return records where the 'module' field is greater than or equal to specified value.
 
 =item * B<module.not_contains> => I<str>
 
-{en_US Only return records where the 'module' field does not contain specified text}.
+Only return records where the 'module' field does not contain specified text.
 
 =item * B<module.not_in> => I<array[str]>
 
-{en_US Only return records where the 'module' field is not in the specified values}.
+Only return records where the 'module' field is not in the specified values.
 
 =item * B<module.xmax> => I<str>
 
-{en_US Only return records where the 'module' field is less than specified value}.
+Only return records where the 'module' field is less than specified value.
 
 =item * B<module.xmin> => I<str>
 
-{en_US Only return records where the 'module' field is greater than specified value}.
+Only return records where the 'module' field is greater than specified value.
 
 =item * B<name> => I<str>
 
-{en_US Only return records where the 'name' field equals specified value}.
+Only return records where the 'name' field equals specified value.
 
 =item * B<name.contains> => I<str>
 
-{en_US Only return records where the 'name' field contains specified text}.
+Only return records where the 'name' field contains specified text.
 
 =item * B<name.in> => I<array[str]>
 
-{en_US Only return records where the 'name' field is in the specified values}.
+Only return records where the 'name' field is in the specified values.
 
 =item * B<name.is> => I<str>
 
-{en_US Only return records where the 'name' field equals specified value}.
+Only return records where the 'name' field equals specified value.
 
 =item * B<name.isnt> => I<str>
 
-{en_US Only return records where the 'name' field does not equal specified value}.
+Only return records where the 'name' field does not equal specified value.
 
 =item * B<name.max> => I<str>
 
-{en_US Only return records where the 'name' field is less than or equal to specified value}.
+Only return records where the 'name' field is less than or equal to specified value.
 
 =item * B<name.min> => I<str>
 
-{en_US Only return records where the 'name' field is greater than or equal to specified value}.
+Only return records where the 'name' field is greater than or equal to specified value.
 
 =item * B<name.not_contains> => I<str>
 
-{en_US Only return records where the 'name' field does not contain specified text}.
+Only return records where the 'name' field does not contain specified text.
 
 =item * B<name.not_in> => I<array[str]>
 
-{en_US Only return records where the 'name' field is not in the specified values}.
+Only return records where the 'name' field is not in the specified values.
 
 =item * B<name.xmax> => I<str>
 
-{en_US Only return records where the 'name' field is less than specified value}.
+Only return records where the 'name' field is less than specified value.
 
 =item * B<name.xmin> => I<str>
 
-{en_US Only return records where the 'name' field is greater than specified value}.
+Only return records where the 'name' field is greater than specified value.
 
 =item * B<notice> => I<str>
 
-{en_US Only return records where the 'notice' field equals specified value}.
+Only return records where the 'notice' field equals specified value.
 
 =item * B<notice.contains> => I<str>
 
-{en_US Only return records where the 'notice' field contains specified text}.
+Only return records where the 'notice' field contains specified text.
 
 =item * B<notice.in> => I<array[str]>
 
-{en_US Only return records where the 'notice' field is in the specified values}.
+Only return records where the 'notice' field is in the specified values.
 
 =item * B<notice.is> => I<str>
 
-{en_US Only return records where the 'notice' field equals specified value}.
+Only return records where the 'notice' field equals specified value.
 
 =item * B<notice.isnt> => I<str>
 
-{en_US Only return records where the 'notice' field does not equal specified value}.
+Only return records where the 'notice' field does not equal specified value.
 
 =item * B<notice.max> => I<str>
 
-{en_US Only return records where the 'notice' field is less than or equal to specified value}.
+Only return records where the 'notice' field is less than or equal to specified value.
 
 =item * B<notice.min> => I<str>
 
-{en_US Only return records where the 'notice' field is greater than or equal to specified value}.
+Only return records where the 'notice' field is greater than or equal to specified value.
 
 =item * B<notice.not_contains> => I<str>
 
-{en_US Only return records where the 'notice' field does not contain specified text}.
+Only return records where the 'notice' field does not contain specified text.
 
 =item * B<notice.not_in> => I<array[str]>
 
-{en_US Only return records where the 'notice' field is not in the specified values}.
+Only return records where the 'notice' field is not in the specified values.
 
 =item * B<notice.xmax> => I<str>
 
-{en_US Only return records where the 'notice' field is less than specified value}.
+Only return records where the 'notice' field is less than specified value.
 
 =item * B<notice.xmin> => I<str>
 
-{en_US Only return records where the 'notice' field is greater than specified value}.
+Only return records where the 'notice' field is greater than specified value.
 
-=item * B<q> => I<str>
+=item * B<query> => I<str>
 
-{en_US Search}.
+Search.
 
 =item * B<sort> => I<str>
 
-{en_US Order records according to certain field(s)}.
+Order records according to certain field(s).
 
-{en_US 
 A list of field names separated by comma. Each field can be prefixed with '-' to
 specify descending order instead of the default ascending.
-}
 
 =item * B<text> => I<str>
 
-{en_US Only return records where the 'text' field equals specified value}.
+Only return records where the 'text' field equals specified value.
 
 =item * B<text.contains> => I<str>
 
-{en_US Only return records where the 'text' field contains specified text}.
+Only return records where the 'text' field contains specified text.
 
 =item * B<text.in> => I<array[str]>
 
-{en_US Only return records where the 'text' field is in the specified values}.
+Only return records where the 'text' field is in the specified values.
 
 =item * B<text.is> => I<str>
 
-{en_US Only return records where the 'text' field equals specified value}.
+Only return records where the 'text' field equals specified value.
 
 =item * B<text.isnt> => I<str>
 
-{en_US Only return records where the 'text' field does not equal specified value}.
+Only return records where the 'text' field does not equal specified value.
 
 =item * B<text.max> => I<str>
 
-{en_US Only return records where the 'text' field is less than or equal to specified value}.
+Only return records where the 'text' field is less than or equal to specified value.
 
 =item * B<text.min> => I<str>
 
-{en_US Only return records where the 'text' field is greater than or equal to specified value}.
+Only return records where the 'text' field is greater than or equal to specified value.
 
 =item * B<text.not_contains> => I<str>
 
-{en_US Only return records where the 'text' field does not contain specified text}.
+Only return records where the 'text' field does not contain specified text.
 
 =item * B<text.not_in> => I<array[str]>
 
-{en_US Only return records where the 'text' field is not in the specified values}.
+Only return records where the 'text' field is not in the specified values.
 
 =item * B<text.xmax> => I<str>
 
-{en_US Only return records where the 'text' field is less than specified value}.
+Only return records where the 'text' field is less than specified value.
 
 =item * B<text.xmin> => I<str>
 
-{en_US Only return records where the 'text' field is greater than specified value}.
+Only return records where the 'text' field is greater than specified value.
 
 =item * B<url> => I<str>
 
-{en_US Only return records where the 'url' field equals specified value}.
+Only return records where the 'url' field equals specified value.
 
 =item * B<url.contains> => I<str>
 
-{en_US Only return records where the 'url' field contains specified text}.
+Only return records where the 'url' field contains specified text.
 
 =item * B<url.in> => I<array[str]>
 
-{en_US Only return records where the 'url' field is in the specified values}.
+Only return records where the 'url' field is in the specified values.
 
 =item * B<url.is> => I<str>
 
-{en_US Only return records where the 'url' field equals specified value}.
+Only return records where the 'url' field equals specified value.
 
 =item * B<url.isnt> => I<str>
 
-{en_US Only return records where the 'url' field does not equal specified value}.
+Only return records where the 'url' field does not equal specified value.
 
 =item * B<url.max> => I<str>
 
-{en_US Only return records where the 'url' field is less than or equal to specified value}.
+Only return records where the 'url' field is less than or equal to specified value.
 
 =item * B<url.min> => I<str>
 
-{en_US Only return records where the 'url' field is greater than or equal to specified value}.
+Only return records where the 'url' field is greater than or equal to specified value.
 
 =item * B<url.not_contains> => I<str>
 
-{en_US Only return records where the 'url' field does not contain specified text}.
+Only return records where the 'url' field does not contain specified text.
 
 =item * B<url.not_in> => I<array[str]>
 
-{en_US Only return records where the 'url' field is not in the specified values}.
+Only return records where the 'url' field is not in the specified values.
 
 =item * B<url.xmax> => I<str>
 
-{en_US Only return records where the 'url' field is less than specified value}.
+Only return records where the 'url' field is less than specified value.
 
 =item * B<url.xmin> => I<str>
 
-{en_US Only return records where the 'url' field is greater than specified value}.
+Only return records where the 'url' field is greater than specified value.
 
 =item * B<version> => I<str>
 
-{en_US Only return records where the 'version' field equals specified value}.
+Only return records where the 'version' field equals specified value.
 
 =item * B<version.contains> => I<str>
 
-{en_US Only return records where the 'version' field contains specified text}.
+Only return records where the 'version' field contains specified text.
 
 =item * B<version.in> => I<array[str]>
 
-{en_US Only return records where the 'version' field is in the specified values}.
+Only return records where the 'version' field is in the specified values.
 
 =item * B<version.is> => I<str>
 
-{en_US Only return records where the 'version' field equals specified value}.
+Only return records where the 'version' field equals specified value.
 
 =item * B<version.isnt> => I<str>
 
-{en_US Only return records where the 'version' field does not equal specified value}.
+Only return records where the 'version' field does not equal specified value.
 
 =item * B<version.max> => I<str>
 
-{en_US Only return records where the 'version' field is less than or equal to specified value}.
+Only return records where the 'version' field is less than or equal to specified value.
 
 =item * B<version.min> => I<str>
 
-{en_US Only return records where the 'version' field is greater than or equal to specified value}.
+Only return records where the 'version' field is greater than or equal to specified value.
 
 =item * B<version.not_contains> => I<str>
 
-{en_US Only return records where the 'version' field does not contain specified text}.
+Only return records where the 'version' field does not contain specified text.
 
 =item * B<version.not_in> => I<array[str]>
 
-{en_US Only return records where the 'version' field is not in the specified values}.
+Only return records where the 'version' field is not in the specified values.
 
 =item * B<version.xmax> => I<str>
 
-{en_US Only return records where the 'version' field is less than specified value}.
+Only return records where the 'version' field is less than specified value.
 
 =item * B<version.xmin> => I<str>
 
-{en_US Only return records where the 'version' field is greater than specified value}.
+Only return records where the 'version' field is greater than specified value.
 
 =item * B<with.text> => I<bool> (default: 0)
 
-{en_US Show field 'with'}.
+Show field 'with'.
 
 =item * B<with_field_names> => I<bool>
 
-{en_US Return field names in each record (as hash/associative array)}.
+Return field names in each record (as hash/associative array).
 
-{en_US 
 When enabled, function will return each record as hash/associative array
 (field name => value pairs). Otherwise, function will return each record
 as list/array (field value, field value, ...).
-}
 
 =back
 
@@ -556,12 +556,6 @@ that contains extra information.
 
 Return value:  (any)
 
-=head1 SEE ALSO
-
-L<Software::License>
-
-L<App::Software::License> to print out license text
-
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/App-ListSoftwareLicenses>.
